/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.server.bo;

import static javax.persistence.InheritanceType.JOINED;
import static javax.persistence.TemporalType.TIMESTAMP;

import java.util.Date;

import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;

import org.hibernate.annotations.Index;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
@Entity
@Inheritance(strategy=JOINED)
@Table(name="HIT")
public class Hit {
	
	@Id
	@GeneratedValue
	@Column(name="hitId")
	protected Long mId;
	
	@ManyToOne
	@JoinColumn(name="parentId")
	protected Hit mParent;
	
	@ManyToOne
	@JoinColumn(name="featureId")
	protected Feature mFeature;
	
	@ManyToOne
	@JoinColumn(name="versionId")
	protected ApplicationVersion mVersion;
	
	@ManyToOne
	@JoinColumn(name="hostId")
	protected Host mHost;
	
	@ManyToOne
	@JoinColumn(name="userId")
	protected User mUser;
	
	@ManyToOne
	@JoinColumn(name="clientHostId")
	protected ClientHost mClientHost;

	@Basic
	@Temporal(TIMESTAMP)
	@Column(name="hitDate")
	@Index(name="hitDateIdx", columnNames = "hitDate")
	protected Date mHitDate;
	
	@ManyToOne
	@JoinColumn(name="hitResult")
	protected HitResult mResult;
	
	@ManyToOne
	@JoinColumn(name="delayType")
	protected DelayType mDelayType;
	
	@Basic
	@Column(name="hitDelay")
	protected Long mDelay;
	
	@Basic
	@Column(name="blockingCount")
	protected Long mBlockingCount;
	
	@Basic
	@Column(name="blockingDelay")
	protected Long mBlockingDelay;
	
	@Basic
	@Column(name="cpuTime")
	protected Long mCpuTime;
	
	@Basic
	@Column(name="cpuUserTime")
	protected Long mCpuUserTime;
	
	@Basic
	@Column(name="waitCount")
	protected Long mWaitCount;
	
	@Basic
	@Column(name="waitDelay")
	protected Long mWaitDelay;

	/**
	 * @return the hitId
	 */
	public Long getId() {
		return mId;
	}

	/**
	 * @param hitId the hitId to set
	 */
	public void setId(Long hitId) {
		this.mId = hitId;
	}
	
	/**
     * @return the parent
     */
    public Hit getParent()
    {
    	return mParent;
    }

	/**
     * @param parent the parent to set
     */
    public void setParent(Hit parent)
    {
    	mParent = parent;
    }

	/**
	 * @return the feature
	 */
	public Feature getFeature() {
		return mFeature;
	}

	/**
	 * @param feature the feature to set
	 */
	public void setFeature(Feature feature) {
		this.mFeature = feature;
	}

	/**
	 * @return the applicationVersion
	 */
	public ApplicationVersion getVersion() {
		return mVersion;
	}

	/**
	 * @param applicationVersion the applicationVersion to set
	 */
	public void setVersion(ApplicationVersion applicationVersion) {
		this.mVersion = applicationVersion;
	}

	/**
	 * @return the host
	 */
	public Host getHost() {
		return mHost;
	}

	/**
	 * @param host the host to set
	 */
	public void setHost(Host host) {
		this.mHost = host;
	}

	/**
	 * @return the user
	 */
	public User getUser() {
		return mUser;
	}

	/**
	 * @param user the user to set
	 */
	public void setUser(User user) {
		this.mUser = user;
	}

	/**
	 * @return the clientHost
	 */
	public ClientHost getClientHost() {
		return mClientHost;
	}

	/**
	 * @param clientHost the clientHost to set
	 */
	public void setClientHost(ClientHost clientHost) {
		this.mClientHost = clientHost;
	}

	/**
	 * @return the hitDate
	 */
	public Date getHitDate() {
		return mHitDate;
	}

	/**
	 * @param hitDate the hitDate to set
	 */
	public void setHitDate(Date hitDate) {
		this.mHitDate = hitDate;
	}

	/**
	 * @return the result
	 */
	public HitResult getResult() {
		return mResult;
	}

	/**
	 * @param result the result to set
	 */
	public void setResult(HitResult result) {
		this.mResult = result;
	}

	/**
	 * @return the delayType
	 */
	public DelayType getDelayType() {
		return mDelayType;
	}

	/**
	 * @param delayType the delayType to set
	 */
	public void setDelayType(DelayType delayType) {
		this.mDelayType = delayType;
	}

	/**
	 * @return the delay
	 */
	public Long getDelay() {
		return mDelay;
	}

	/**
	 * @param delay the delay to set
	 */
	public void setDelay(Long delay) {
		this.mDelay = delay;
	}

	/**
	 * @return the blockingCount
	 */
	public Long getBlockingCount() {
		return mBlockingCount;
	}

	/**
	 * @param blockingCount the blockingCount to set
	 */
	public void setBlockingCount(Long blockingCount) {
		this.mBlockingCount = blockingCount;
	}

	/**
	 * @return the blockingDelay
	 */
	public Long getBlockingDelay() {
		return mBlockingDelay;
	}

	/**
	 * @param blockingDelay the blockingDelay to set
	 */
	public void setBlockingDelay(Long blockingDelay) {
		this.mBlockingDelay = blockingDelay;
	}

	/**
	 * @return the cpuTime
	 */
	public Long getCpuTime() {
		return mCpuTime;
	}

	/**
	 * @param cpuTime the cpuTime to set
	 */
	public void setCpuTime(Long cpuTime) {
		this.mCpuTime = cpuTime;
	}

	/**
	 * @return the cpuUserTime
	 */
	public Long getCpuUserTime() {
		return mCpuUserTime;
	}

	/**
	 * @param cpuUserTime the cpuUserTime to set
	 */
	public void setCpuUserTime(Long cpuUserTime) {
		this.mCpuUserTime = cpuUserTime;
	}

	/**
	 * @return the waitCount
	 */
	public Long getWaitCount() {
		return mWaitCount;
	}

	/**
	 * @param waitCount the waitCount to set
	 */
	public void setWaitCount(Long waitCount) {
		this.mWaitCount = waitCount;
	}

	/**
	 * @return the waitDelay
	 */
	public Long getWaitDelay() {
		return mWaitDelay;
	}

	/**
	 * @param waitDelay the waitDelay to set
	 */
	public void setWaitDelay(Long waitDelay) {
		this.mWaitDelay = waitDelay;
	}
}
